package de.kif.backend

import com.fasterxml.jackson.databind.SerializationFeature
import de.kif.backend.route.*
import de.kif.backend.route.api.*
import de.kif.backend.util.pushService
import io.ktor.application.Application
import io.ktor.application.install
import io.ktor.features.*
import io.ktor.http.content.files
import io.ktor.http.content.static
import io.ktor.jackson.jackson
import io.ktor.routing.routing
import io.ktor.websocket.WebSockets
import kotlinx.serialization.ImplicitReflectionSerializer

@ImplicitReflectionSerializer
fun Application.main() {
    install(DefaultHeaders)
    install(CallLogging)
    install(ConditionalHeaders)
    install(Compression)
    install(DataConversion)
    install(WebSockets)

    install(ContentNegotiation) {
        jackson {
            enable(SerializationFeature.INDENT_OUTPUT) // Pretty Prints the JSON
        }
    }

    security()

    routing {
        static("/static") {
            files(Resources.directory)
        }

        // UI routes
        overview()
        calendar()
        login()
        account()

        workGroup()
        track()
        room()
        user()

        // RESTful routes
        authenticateApi()

        roomApi()
        scheduleApi()
        trackApi()
        userApi()
        workGroupApi()
        constraintsApi()

        // Web socket push notifications
        pushService()
    }
}
