package de.kif.backend.database

import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import org.jetbrains.exposed.sql.Database
import org.jetbrains.exposed.sql.SchemaUtils
import org.jetbrains.exposed.sql.transactions.TransactionManager
import org.jetbrains.exposed.sql.transactions.transaction
import java.sql.Connection.TRANSACTION_SERIALIZABLE


object Connection {
    fun init() {
        Database.connect("jdbc:sqlite:portal.db", "org.sqlite.JDBC")
        TransactionManager.manager.defaultIsolationLevel = TRANSACTION_SERIALIZABLE

        transaction {
            SchemaUtils.create(
                DbTrack, DbWorkGroup,
                DbRoom, DbSchedule,
                DbUser, DbUserPermission,
                DbPost
            )
        }
    }
}

suspend fun <T> dbQuery(block: () -> T): T = withContext(Dispatchers.IO) {
    transaction { block() }
}
